# TerminalOptions

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**echo** | **int** |  | [optional] 
**terminal** | **bool** |  | [optional] 
**terminal_height** | **int** |  | [optional] 
**terminal_type** | **str** |  | [optional] 
**terminal_width** | **int** |  | [optional] 
**ty_i_speed** | **int** |  | [optional] 
**ty_o_speed** | **int** |  | [optional] 

[[Back to Model list]](README.md#documentation-for-models) [[Back to API list]](README.md#documentation-for-api-endpoints) [[Back to README]](README.md)


